import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:awc_shared_pref/awc_shared_pref.dart';

void main() {
  const MethodChannel channel = MethodChannel('awc_shared_pref');

  TestWidgetsFlutterBinding.ensureInitialized();

  setUp(() {
    channel.setMockMethodCallHandler((MethodCall methodCall) async {
      return '42';
    });
  });

  tearDown(() {
    channel.setMockMethodCallHandler(null);
  });

  test('getPlatformVersion', () async {
    expect(await AwcSharedPref.platformVersion, '42');
  });

  // String

  test('setStringPref', () async {
    expect(await AwcSharedPref().setString("testString", "test 123"), true);
  });

  test('getStringPref', () async {
    expect(await AwcSharedPref().getString("testString", "test1"), "test 123");
  });

  test('getStringPrefDefault', () async {
    expect(
        await AwcSharedPref().getString("testStringDefault", "test1"), "test1");
  });

  // Int

  test('setIntPref', () async {
    expect(await AwcSharedPref().setInt("testInt", 123), true);
  });

  test('getIntPref', () async {
    expect(await AwcSharedPref().getInt("testInt", 5), 123);
  });

  test('getIntPrefDefault', () async {
    expect(await AwcSharedPref().getInt("testIntDefault", 5), 5);
  });

  // Double

  test('setDoublePref', () async {
    expect(await AwcSharedPref().setDouble("testDouble", 123.123), true);
  });

  test('getDoublePref', () async {
    expect(await AwcSharedPref().getDouble("testDouble", 5.5), 123.123);
  });

  test('getDoublePrefDefault', () async {
    expect(await AwcSharedPref().getDouble("testDoubleDefault", 5.5), 5.5);
  });

  // Bool

  test('setBoolPref', () async {
    expect(await AwcSharedPref().setBool("testBool", true), true);
  });

  test('getBoolPref', () async {
    expect(await AwcSharedPref().getBool("testBool", false), true);
  });

  test('getBoolPrefDefault', () async {
    expect(await AwcSharedPref().getBool("testBoolDefault", false), false);
  });

  // empty

  test('setEmptyPref', () async {
    expect(await AwcSharedPref().setEmpty(), true);
  });
}
